@@ -2,12 +2,13 @@ from functools import partial
 from typing import Dict, Final, Tuple, Union
 
 import boto3
+from _common.session_azure import get_session as azure_get_session
 from ec2instances.ec2_instance_mapping import Ec2AllInstancesData
 from rich.console import Console
 from rich.table import Table
 
-from pyclvm._common.azure_instance_mapping import AzureComputeAllInstancesData
 from pyclvm._common.gcp_instance_mapping import GcpComputeAllInstancesData
+from pyclvm.login import _login_aws
 from pyclvm.plt import (
     _default_platform,
     _get_supported_platforms,
@@ -93,7 +94,7 @@ def _ls_aws(**kwargs: str) -> None:
     if current_profile:
         boto3.setup_default_session(profile_name=current_profile)
 
-    instances = Ec2AllInstancesData()
+    instances = Ec2AllInstancesData(auth_callback=_login_aws)
     sts_client = boto3.client("sts")
 
     account = sts_client.get_caller_identity().Account
@@ -158,17 +159,18 @@ def _ls_azure(**kwargs: str) -> None:
         None
 
     """
-    instances = AzureComputeAllInstancesData(**kwargs)
-    table = Table(title=f"{instances.session.subscription_name} Azure Instances")
+    _session = azure_get_session()
+
+    table = Table(title=f"{_session.subscription_name} Azure Instances")
     for column in _COLUMNS:
         table.add_column(column, justify="left", no_wrap=True)
 
-    for instance_id, instance_name, state in instances:
+    for instance, params in _session.instances.items():
         table.add_row(
             *(
-                str(instance_id),
-                instance_name,
-                f"[{_STATE_COLOR_AZURE[state]}]{state}",
+                str(params["instance_id"]),
+                instance,
+                f"[{_STATE_COLOR_AZURE[params['state']]}]{params['state']}",
             )
         )
     console = Console()
