@@ -3,7 +3,6 @@ import getpass
 import os
 import platform
 import sys
-import time
 from functools import partial
 from os.path import exists, join
 from shutil import copyfile, copymode, move
@@ -19,7 +18,6 @@ from pyclvm._common.azure_instance_mapping import (
     AzureRemoteShellMapping,
     AzureRemoteShellProxy,
 )
-from pyclvm._common.azure_instance_proxy import next_free_port
 from pyclvm._common.gcp_instance_mapping import (
     GcpRemoteShellMapping,
     GcpRemoteShellProxy,
@@ -108,9 +106,8 @@ def _new_azure(instance_name: str, **kwargs: str) -> None:
 
 # ---
 def _aws_config_lines(instance: Ec2RemoteShellProxy, **kwargs: str) -> List:
-    profile = kwargs.get("profile", "default")
+    profile = kwargs.pop("profile", "default")
     private_key_name, pubkey = _save_keys(profile, instance.name)
-    global cloud_platform
 
     proxy_data = {
         "identity_file": private_key_name,
@@ -119,20 +116,14 @@ def _aws_config_lines(instance: Ec2RemoteShellProxy, **kwargs: str) -> List:
     }
     # ---
     instance.start(wait=True)
-    timeout = 10
-    while timeout > 0:
-        print(".", end="")
-        time.sleep(1)
-        timeout -= 1
-    print()
+    print("*" * 10)
     # ---
     instance.execute(
-        "pip3 install --upgrade authk",
+        "pip3 install --upgrade authk --quiet",
         f'runuser -u ssm-user -- authk add "{pubkey}"',
         **kwargs,
     )
     # ---
-    instance.stop(wait=False)
     return _config_lines(instance.name, proxy_data)
 
 
@@ -146,7 +137,6 @@ def _gcp_config_lines(instance: GcpRemoteShellProxy, **kwargs: str) -> List:
 # ---
 def _azure_config_lines(instance: AzureRemoteShellProxy, **kwargs: str) -> List:
     profile = kwargs.get("profile", "default")
-    global cloud_platform
 
     account = kwargs.get("account")
     key = kwargs.get("key")
@@ -158,10 +148,9 @@ def _azure_config_lines(instance: AzureRemoteShellProxy, **kwargs: str) -> List:
         )
         sys.exit(-1)
 
-    port = next_free_port(port=22060, max_port=22960)
     proxy_data = {
         "identity_file": key,
-        "proxy_command": f"{str(_MAIN)} ssh start {instance.name} {port} profile={profile} platform={cloud_platform} account={account} key={os.path.normpath(key)}",
+        "proxy_command": f"{str(_MAIN)} ssh start {instance.name} 0 profile={profile} platform={cloud_platform} account={account} key={os.path.normpath(key)}",
         "user_name": account,
     }
     return _config_lines(instance.name, proxy_data)
@@ -218,7 +207,6 @@ def _save_keys(profile: str, instance_name: str) -> Tuple[str, str]:
 # ----------------------------------------
 # --- Analysis and writing config file ---
 def _analyze_config(instance_name: str) -> Tuple[int, int]:
-    global cloud_platform
 
     previous_conf_pos = -1
     wildcard_conf_pos = -1
@@ -264,7 +252,7 @@ def _write(
     skip_flag = True
 
     with os.fdopen(tmp_file, "w", encoding="utf8") as dst_file:
-        with open(_SSH_CONFIG) as src_file:
+        with open(_SSH_CONFIG, encoding="utf-8") as src_file:
             if position < 0:
                 position = len(src_file.readlines()) - 1
                 src_file.seek(0)
@@ -344,13 +332,14 @@ def _create_config_block(
     Returns:
         None
     """
-    global cloud_platform
 
     config_lines = {
         "aws": partial(_aws_config_lines, instance, **kwargs),
         "gcp": partial(_gcp_config_lines, instance, **kwargs),
         "azure": partial(_azure_config_lines, instance, **kwargs),
-    }[cloud_platform]()
+    }[
+        cloud_platform
+    ]()  # type: ignore
 
     os.makedirs(name=_SSH_DIR, mode=0o700, exist_ok=True)
 
@@ -381,7 +370,6 @@ def _get_gcp_proxy_data(instance: GcpRemoteShellProxy, **kwargs: str) -> Dict:
     Returns:
         (jdict) Retrieved data
     """
-    global cloud_platform
 
     profile = kwargs.get("profile", "default")
     try:
@@ -390,8 +378,8 @@ def _get_gcp_proxy_data(instance: GcpRemoteShellProxy, **kwargs: str) -> Dict:
             raise ValueError(
                 "No username/account, use [--account=username@company.com]"
             )
-        for c in ("@", ".", "-"):
-            account = account.replace(c, "_")
+        for char in "@", ".", "-":
+            account = account.replace(char, "_")
 
         return {
             "identity_file": _GOOGLE_SSH_PRIV_KEY,
